is_enabled

Function is_enabled 

pub fn is_enabled() -> bool
Check if debug tracing is enabled.

This function is inlined and after the first call, compiles down to a single static bool load - effectively zero cost when disabled.