pub struct Subscription { /* private fields */ }Expand description
RAII guard for a subscriber callback.
Dropping the Subscription causes the associated callback to become
unreachable (the strong Rc is dropped, so the Weak in the
observable’s subscriber list will fail to upgrade on the next
notification cycle).