check_schema_compat

Function check_schema_compat 

pub fn check_schema_compat(
    kind: SchemaKind,
    writer_version: &str,
) -> CompatCheckResult
Check compatibility between a reader (current) and writer version.

The reader version is always the current version for the given schema kind. The writer version is the version found in the data being read.

Emits a trace.compat_check tracing span and increments trace_compat_failures_total on incompatibility.