pub struct MacroPlayback { /* private fields */ }Expand description
Deterministic playback scheduler with speed and looping controls.
Invariants:
- Event order is preserved.
elapsedis monotonic for a givenadvancesequence.- No events are emitted without their cumulative delay being satisfied.
Failure modes:
- If total duration is zero and looping is enabled, looping is ignored to
avoid infinite emission within a single
advancecall.
Implementations
Sourceimpl MacroPlayback
impl MacroPlayback
Sourcepub fn new(input_macro: InputMacro) -> Self
pub fn new(input_macro: InputMacro) -> Self
Create a new playback scheduler for the given macro.
Sourcepub fn with_speed(self, speed: f64) -> Self
pub fn with_speed(self, speed: f64) -> Self
Fluent speed setter.
Sourcepub fn set_looping(&mut self, looping: bool)
pub fn set_looping(&mut self, looping: bool)
Enable or disable looping.
Sourcepub fn with_looping(self, looping: bool) -> Self
pub fn with_looping(self, looping: bool) -> Self
Fluent looping setter.