classify_schema_compat

Function classify_schema_compat 

pub fn classify_schema_compat(
    kind: SchemaKind,
    writer_version: &str,
) -> CompatCheckResult
Classify compatibility between a reader (current) and writer version without emitting tracing spans or metrics.

The reader version is always the current version for the given schema kind. The writer version is the version found in the data being read.